"""
Setup script for acton-agent package.
This file is maintained for backward compatibility.
The main configuration is in pyproject.toml.
"""

from setuptools import setup


if __name__ == "__main__":
    setup()
